# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/l10n/term.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65olymp/l10n/term.proto\x12\x0b\x65olymp.l10n\"\x9f\x01\n\x04Term\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.eolymp.l10n.Term.Status\".\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0e\n\nDEPRECATED\x10\x02\x42+Z)github.com/eolymp/go-sdk/eolymp/l10n;l10nb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.l10n.term_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/l10n;l10n'
  _TERM._serialized_start=40
  _TERM._serialized_end=199
  _TERM_STATUS._serialized_start=153
  _TERM_STATUS._serialized_end=199
# @@protoc_insertion_point(module_scope)
